@@ -902,7 +902,7 @@ def marketing_busifavor_stock_modify(self,
         params.update({'stock_send_rule': stock_send_rule})
     if notify_config:
         params.update({'notify_config': notify_config})
-    return self._core.request(path, method=RequestType.POST, data=params)
+    return self._core.request(path, method=RequestType.PATCH, data=params)
 
 
 def marketing_busifavor_coupon_return(self, coupon_code, stock_id, return_request_no):
@@ -1019,3 +1019,21 @@ def marketing_busifavor_subsidy_query(self, subsidy_receipt_id):
     else:
         raise Exception('subsidy_receipt_id is not assigned.')
     return self._core.request(path)
+
+
+def industry_coupon_token(self, open_id, coupon_list=[]):
+    """出行券切卡组件预下单
+    :param open_id: 用户在商户AppID下的唯一标识，该用户为后续拉起切卡组件的用户。示例值：'obLatjrR8kUDlj4-nofQsPAJAAFI'
+    :param coupon_list: 用户最近领取的出行券列表。示例值：[{"coupon_id": "11004999626", "stock_id": 16474341}]
+    """
+    params = {}
+    if open_id:
+        params.update({'open_id': open_id})
+    else:
+        raise Exception('open_id is not assigned.')
+    if coupon_list:
+        params.update({'coupon_list': coupon_list})
+    else:
+        raise Exception('coupon_list is not assigned.')
+    path = '/v3/industry-coupon/tokens'
+    return self._core.request(path, method=RequestType.POST, data=params)
